==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/ConnectedEnvironmentsStorageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin

import com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs.builder
import com.pulumi.azurenative.app.kotlin.inputs.ConnectedEnvironmentStoragePropertiesArgs
import com.pulumi.azurenative.app.kotlin.inputs.ConnectedEnvironmentStoragePropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Storage resource for connectedEnvironment.
 * Azure REST API version: 2022-10-01.
 * Other available API versions: 2023-04-01-preview, 2023-05-01, 2023-05-02-preview, 2023-08-01-preview, 2023-11-02-preview.
 * ## Example Usage
 * ### Create or update environments storage
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var connectedEnvironmentsStorage = new AzureNative.App.ConnectedEnvironmentsStorage("connectedEnvironmentsStorage", new()
 *     {
 *         ConnectedEnvironmentName = "env",
 *         Properties = new AzureNative.App.Inputs.ConnectedEnvironmentStoragePropertiesArgs
 *         {
 *             AzureFile = new AzureNative.App.Inputs.AzureFilePropertiesArgs
 *             {
 *                 AccessMode = "ReadOnly",
 *                 AccountKey = "key",
 *                 AccountName = "account1",
 *                 ShareName = "share1",
 *             },
 *         },
 *         ResourceGroupName = "examplerg",
 *         StorageName = "jlaw-demo1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/app/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := app.NewConnectedEnvironmentsStorage(ctx, "connectedEnvironmentsStorage", &app.ConnectedEnvironmentsStorageArgs{
 * 			ConnectedEnvironmentName: pulumi.String("env"),
 * 			Properties: app.ConnectedEnvironmentStorageResponseProperties{
 * 				AzureFile: &app.AzureFilePropertiesArgs{
 * 					AccessMode:  pulumi.String("ReadOnly"),
 * 					AccountKey:  pulumi.String("key"),
 * 					AccountName: pulumi.String("account1"),
 * 					ShareName:   pulumi.String("share1"),
 * 				},
 * 			},
 * 			ResourceGroupName: pulumi.String("examplerg"),
 * 			StorageName:       pulumi.String("jlaw-demo1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.app.ConnectedEnvironmentsStorage;
 * import com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var connectedEnvironmentsStorage = new ConnectedEnvironmentsStorage("connectedEnvironmentsStorage", ConnectedEnvironmentsStorageArgs.builder()
 *             .connectedEnvironmentName("env")
 *             .properties(Map.of("azureFile", Map.ofEntries(
 *                 Map.entry("accessMode", "ReadOnly"),
 *                 Map.entry("accountKey", "key"),
 *                 Map.entry("accountName", "account1"),
 *                 Map.entry("shareName", "share1")
 *             )))
 *             .resourceGroupName("examplerg")
 *             .storageName("jlaw-demo1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:app:ConnectedEnvironmentsStorage jlaw-demo1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.App/connectedEnvironments/{connectedEnvironmentName}/storages/{storageName}
 * ```
 * @property connectedEnvironmentName Name of the Environment.
 * @property properties Storage properties
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property storageName Name of the storage.
 */
public data class ConnectedEnvironmentsStorageArgs(
    public val connectedEnvironmentName: Output<String>? = null,
    public val properties: Output<ConnectedEnvironmentStoragePropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val storageName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs> {
    override fun toJava(): com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs =
        com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs.builder()
            .connectedEnvironmentName(connectedEnvironmentName?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .storageName(storageName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectedEnvironmentsStorageArgs].
 */
@PulumiTagMarker
public class ConnectedEnvironmentsStorageArgsBuilder internal constructor() {
    private var connectedEnvironmentName: Output<String>? = null

    private var properties: Output<ConnectedEnvironmentStoragePropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var storageName: Output<String>? = null

    /**
     * @param value Name of the Environment.
     */
    @JvmName("xaamkngqnxlcrekd")
    public suspend fun connectedEnvironmentName(`value`: Output<String>) {
        this.connectedEnvironmentName = value
    }

    /**
     * @param value Storage properties
     */
    @JvmName("srcimtvukmrunsje")
    public suspend fun properties(`value`: Output<ConnectedEnvironmentStoragePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("nkgyhvybteqdexwe")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Name of the storage.
     */
    @JvmName("sslsqcrovuniamqm")
    public suspend fun storageName(`value`: Output<String>) {
        this.storageName = value
    }

    /**
     * @param value Name of the Environment.
     */
    @JvmName("bqwbxxlwkuuhqwwe")
    public suspend fun connectedEnvironmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectedEnvironmentName = mapped
    }

    /**
     * @param value Storage properties
     */
    @JvmName("fcdidxxrhyxaswmd")
    public suspend fun properties(`value`: ConnectedEnvironmentStoragePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Storage properties
     */
    @JvmName("unitfijntestqyfi")
    public suspend
    fun properties(argument: suspend ConnectedEnvironmentStoragePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ConnectedEnvironmentStoragePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("utdciqakcvcgpcfk")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the storage.
     */
    @JvmName("ysfcsitdbywhvqsr")
    public suspend fun storageName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageName = mapped
    }

    internal fun build(): ConnectedEnvironmentsStorageArgs = ConnectedEnvironmentsStorageArgs(
        connectedEnvironmentName = connectedEnvironmentName,
        properties = properties,
        resourceGroupName = resourceGroupName,
        storageName = storageName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/ConnectedEnvironmentsStorageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin

import com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs.builder
import com.pulumi.azurenative.app.kotlin.inputs.ConnectedEnvironmentStoragePropertiesArgs
import com.pulumi.azurenative.app.kotlin.inputs.ConnectedEnvironmentStoragePropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Storage resource for connectedEnvironment.
 * Azure REST API version: 2022-10-01.
 * Other available API versions: 2023-04-01-preview, 2023-05-01, 2023-05-02-preview, 2023-08-01-preview, 2023-11-02-preview.
 * ## Example Usage
 * ### Create or update environments storage
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var connectedEnvironmentsStorage = new AzureNative.App.ConnectedEnvironmentsStorage("connectedEnvironmentsStorage", new()
 *     {
 *         ConnectedEnvironmentName = "env",
 *         Properties = new AzureNative.App.Inputs.ConnectedEnvironmentStoragePropertiesArgs
 *         {
 *             AzureFile = new AzureNative.App.Inputs.AzureFilePropertiesArgs
 *             {
 *                 AccessMode = AzureNative.App.AccessMode.ReadOnly,
 *                 AccountKey = "key",
 *                 AccountName = "account1",
 *                 ShareName = "share1",
 *             },
 *         },
 *         ResourceGroupName = "examplerg",
 *         StorageName = "jlaw-demo1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/app/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := app.NewConnectedEnvironmentsStorage(ctx, "connectedEnvironmentsStorage", &app.ConnectedEnvironmentsStorageArgs{
 * 			ConnectedEnvironmentName: pulumi.String("env"),
 * 			Properties: &app.ConnectedEnvironmentStoragePropertiesArgs{
 * 				AzureFile: &app.AzureFilePropertiesArgs{
 * 					AccessMode:  pulumi.String(app.AccessModeReadOnly),
 * 					AccountKey:  pulumi.String("key"),
 * 					AccountName: pulumi.String("account1"),
 * 					ShareName:   pulumi.String("share1"),
 * 				},
 * 			},
 * 			ResourceGroupName: pulumi.String("examplerg"),
 * 			StorageName:       pulumi.String("jlaw-demo1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.app.ConnectedEnvironmentsStorage;
 * import com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs;
 * import com.pulumi.azurenative.app.inputs.ConnectedEnvironmentStoragePropertiesArgs;
 * import com.pulumi.azurenative.app.inputs.AzureFilePropertiesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var connectedEnvironmentsStorage = new ConnectedEnvironmentsStorage("connectedEnvironmentsStorage", ConnectedEnvironmentsStorageArgs.builder()
 *             .connectedEnvironmentName("env")
 *             .properties(ConnectedEnvironmentStoragePropertiesArgs.builder()
 *                 .azureFile(AzureFilePropertiesArgs.builder()
 *                     .accessMode("ReadOnly")
 *                     .accountKey("key")
 *                     .accountName("account1")
 *                     .shareName("share1")
 *                     .build())
 *                 .build())
 *             .resourceGroupName("examplerg")
 *             .storageName("jlaw-demo1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:app:ConnectedEnvironmentsStorage jlaw-demo1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.App/connectedEnvironments/{connectedEnvironmentName}/storages/{storageName}
 * ```
 * @property connectedEnvironmentName Name of the Environment.
 * @property properties Storage properties
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property storageName Name of the storage.
 */
public data class ConnectedEnvironmentsStorageArgs(
    public val connectedEnvironmentName: Output<String>? = null,
    public val properties: Output<ConnectedEnvironmentStoragePropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val storageName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs> {
    override fun toJava(): com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs =
        com.pulumi.azurenative.app.ConnectedEnvironmentsStorageArgs.builder()
            .connectedEnvironmentName(connectedEnvironmentName?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .storageName(storageName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectedEnvironmentsStorageArgs].
 */
@PulumiTagMarker
public class ConnectedEnvironmentsStorageArgsBuilder internal constructor() {
    private var connectedEnvironmentName: Output<String>? = null

    private var properties: Output<ConnectedEnvironmentStoragePropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var storageName: Output<String>? = null

    /**
     * @param value Name of the Environment.
     */
    @JvmName("ntfdoxxixthqssmc")
    public suspend fun connectedEnvironmentName(`value`: Output<String>) {
        this.connectedEnvironmentName = value
    }

    /**
     * @param value Storage properties
     */
    @JvmName("wcqwpvbrkwusctdr")
    public suspend fun properties(`value`: Output<ConnectedEnvironmentStoragePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("lbvnukknqajkdvdv")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Name of the storage.
     */
    @JvmName("qrsbrroouwtitjwm")
    public suspend fun storageName(`value`: Output<String>) {
        this.storageName = value
    }

    /**
     * @param value Name of the Environment.
     */
    @JvmName("wsbtfdcqmnwwdhoe")
    public suspend fun connectedEnvironmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectedEnvironmentName = mapped
    }

    /**
     * @param value Storage properties
     */
    @JvmName("rjjwigyfrqmgasdo")
    public suspend fun properties(`value`: ConnectedEnvironmentStoragePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Storage properties
     */
    @JvmName("ovsrkubinsppvsej")
    public suspend
    fun properties(argument: suspend ConnectedEnvironmentStoragePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ConnectedEnvironmentStoragePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("unkqauyikusgsqta")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the storage.
     */
    @JvmName("uctdplrexqjwxcbc")
    public suspend fun storageName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageName = mapped
    }

    internal fun build(): ConnectedEnvironmentsStorageArgs = ConnectedEnvironmentsStorageArgs(
        connectedEnvironmentName = connectedEnvironmentName,
        properties = properties,
        resourceGroupName = resourceGroupName,
        storageName = storageName,
    )
}
